using UnityEngine;
using System.Collections;

public static class ColorExtensions
{
    /// <summary>
    /// Returns a copy of the color as transparent.
    /// </summary>
    public static Color GetTransparent(this Color c)
    {
        return new Color(c.r, c.g, c.b, 0f);
    }

    /// <summary>
    /// Returns a copy of the color as transparent with a set alpha.
    /// </summary>
    public static Color GetTransparent(this Color c, float alpha)
    {
        return new Color(c.r, c.g, c.b, alpha);
    }

    /// <summary>
    /// Returns a copy of the color as fully-opaque.
    /// </summary>
    public static Color GetOpaque(this Color c)
    {
        return new Color(c.r, c.g, c.b, 1f);
    }

    /// <summary>
    /// Returns the hex value of this color.
    /// </summary>
    public static string ToHex(this Color c)
    {
        Color32 color = c;

        return color.r.ToString("X2") + color.g.ToString("X2") + color.b.ToString("X2");
    }

    /// <summary>
    /// Returns the hex value of this color.
    /// </summary>
    public static string ToHexWithAlpha(this Color c)
    {
        Color32 color = c;

        return color.r.ToString("X2") + color.g.ToString("X2") + color.b.ToString("X2") + color.a.ToString("X2");
    }

    /// <summary>
    /// Converts this color to the given hex value.
    /// </summary>
    public static Color FromHex(this Color c, string hex)
    {
        // TODO: Could deal with shorthand here. (#ccc)

        c.r = byte.Parse(hex.Substring(0, 2), System.Globalization.NumberStyles.HexNumber);
        c.g = byte.Parse(hex.Substring(2, 2), System.Globalization.NumberStyles.HexNumber);
        c.b = byte.Parse(hex.Substring(4, 2), System.Globalization.NumberStyles.HexNumber);

        if (hex.Length == 8)
            c.a = byte.Parse(hex.Substring(6, 2), System.Globalization.NumberStyles.HexNumber);

        return c;
    }
}
