using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class BodyGrabBehavior : MonoBehaviour
{
	public new Rigidbody2D rigidbody;
	public BodyGrabBehavior otherBody;
	public SpriteRenderer mainSprite;
	public SpriteRenderer chargeSprite;
	public SpriteRenderer overSlot;
	public FixedJoint2D grabJoint;
	public Rigidbody2D friendlyAnchor;
	public GameObject rootObject;
	public ParticleSystem sweat;

	public bool IsGrabbing;

	public int playerNumber = 0;

	private string triggerInput;
	private string xAxisInput;
	private string yAxisInput;

	private CaterpillarBehavior parent;

	[HideInInspector]
	public Sprite
		overSlotOn, overSlotOff;

	public void Setup (CaterpillarBehavior parent)
	{
		this.parent = parent;
	}

	void Start ()
	{
		this.rigidbody = this.GetComponent<Rigidbody2D> ();

		switch (this.playerNumber) {
		case 1:
#if UNITY_STANDALONE_OSX
			this.triggerInput = "LeftTrigger";
#else
			this.triggerInput = "LeftTriggerPC";
#endif
			this.xAxisInput = "LeftX";
			this.yAxisInput = "LeftY";
			break;
		case 0:
#if UNITY_STANDALONE_OSX
			this.triggerInput = "RightTrigger";
			this.xAxisInput = "RightX";
			this.yAxisInput = "RightY";
#else
			this.triggerInput = "RightTriggerPC";
			this.xAxisInput = "RightXPC";
			this.yAxisInput = "RightYPC";
#endif
			break;
		case 3:
#if UNITY_STANDALONE_OSX
			this.triggerInput = "LeftTrigger2";
#else
			this.triggerInput = "LeftTriggerPC2";
#endif
			this.xAxisInput = "LeftX2";
			this.yAxisInput = "LeftY2";
			break;
		case 2:
#if UNITY_STANDALONE_OSX
			this.triggerInput = "RightTrigger2";
			this.xAxisInput = "RightX2";
			this.yAxisInput = "RightY2";
#else
			this.triggerInput = "RightTriggerPC2";
			this.xAxisInput = "RightXPC2";
			this.yAxisInput = "RightYPC2";
#endif
			break;
		}

		LoadImage (playerNumber + 1);
	}

	// Update is called once per frame
	void Update ()
	{
		if (Input.GetAxis (this.triggerInput) >= 0.5f && !this.IsGrabbing) {
			Collider2D[] allCollisions = Physics2D.OverlapCircleAll (this.transform.position, 0.17f);

			List<Collider2D> collisions = allCollisions.Where (x => !x.transform.IsChildOf (this.transform.parent)).ToList ();

			if (collisions.Any (x => x.tag.Equals ("GrabStatic") || x.tag.Equals ("GrabDynamic"))) {
				this.IsGrabbing = true;
				this.otherBody.OtherDidGrab ();
				this.chargeSprite.setAlpha (1f);
				overSlot.sprite = overSlotOn;
				sweat.Play ();

				if (collisions.Any (x => x.tag.Equals ("GrabDynamic"))) {
					SoundManager.instance.PlayGrunt ();

					Collider2D collider = collisions.FirstOrDefault (x => x.tag.Equals ("GrabDynamic"));

					this.grabJoint.anchor = Vector2.zero;
					Vector2 anchor = collider.transform.InverseTransformPoint (this.transform.position);
					this.grabJoint.connectedAnchor = anchor;
					this.grabJoint.connectedBody = collider.GetComponent<Rigidbody2D> ();

					this.grabJoint.enabled = true;
				} else {
					SoundManager.instance.PlayGrunt ();

					this.friendlyAnchor.transform.position = this.transform.position;
					this.grabJoint.connectedBody = this.friendlyAnchor;
					this.grabJoint.connectedAnchor = Vector2.zero;
					this.grabJoint.anchor = Vector2.zero;
				}
				this.grabJoint.enabled = true;

			}
		}
		
		if (this.IsGrabbing && Input.GetAxis (this.triggerInput) <= 0.5f) {
			this.IsGrabbing = false;
			this.otherBody.OtherDidRelease ();
			this.chargeSprite.setAlpha (0f);
			overSlot.sprite = overSlotOff;
			sweat.Stop ();
			
			this.grabJoint.connectedBody = null;
			this.grabJoint.enabled = false;
		}

		Vector2 direction = Input.GetAxis (this.xAxisInput) * Vector2.right + Input.GetAxis (yAxisInput) * Vector2.down;

		if (direction.magnitude > 1f) {
			direction.Normalize ();
		}

		if (this.otherBody.IsGrabbing && !this.IsGrabbing) {
			this.rigidbody.AddForce (direction.normalized * 8f);
		} else {
			this.rigidbody.AddForce (direction.normalized * 4f);
		}
	}

	public void OtherDidGrab ()
	{
		this.rigidbody.gravityScale = 0.25f;
	}

	public void OtherDidRelease ()
	{
		this.rigidbody.gravityScale = 1f;
	}

	public void LoadImage (int num)
	{
		string headAsset = string.Format ("Sprites/cat_head_{0:D2}", num);
		mainSprite.sprite = ResourceTools.Instantiate<Sprite> (headAsset);
		chargeSprite.sprite = ResourceTools.Instantiate<Sprite> (headAsset);

		if (playerNumber % 2 == 0) {
			// eyes
			int assetNum = Random.Range (1, 7);
			string assetOn = string.Format ("Sprites/cat_eyes_{0:D2}_blink", assetNum);
			string assetOff = string.Format ("Sprites/cat_eyes_{0:D2}_idle", assetNum);

			overSlotOn = ResourceTools.Instantiate<Sprite> (assetOn);
			overSlotOff = ResourceTools.Instantiate<Sprite> (assetOff);
		} else {
			// butt
			int assetNum = Random.Range (1, 5);
			string assetOn = string.Format ("Sprites/cat_clench_{0:D2}_on", assetNum);
			string assetOff = string.Format ("Sprites/cat_clench_{0:D2}_off", assetNum);

			overSlotOn = ResourceTools.Instantiate<Sprite> (assetOn);
			overSlotOff = ResourceTools.Instantiate<Sprite> (assetOff);
		}

		overSlot.sprite = overSlotOff;
	}

	public void MarkSavePoint (Transform point)
	{
		parent.SaveLastPosition (point.position); 
	}
}
