﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class CaterpillarBehavior : MonoBehaviour
{
	public BodyGrabBehavior caterHead;
	public BodyGrabBehavior caterTail;

	public ParticleSystem smokePuff;
	public ParticleSystem confettiPuff;

	public Vector3 lastSpawnPoint;

	private Dictionary<Transform, Vector3> originalPositions;

	private bool isDying = false;

	private float deathTime = 0f;
	private float deathTimeMax = 2f;

	void Start ()
	{
		originalPositions = new Dictionary<Transform, Vector3> ();

		Transform[] allTransforms = gameObject.GetComponentsInChildren<Transform> (true);

		for (int i = 0; i < allTransforms.Length; ++i) {
			Transform t = allTransforms [i];

			if (t != transform)
				originalPositions.Add (t, t.localPosition);
		}

		SaveLastPosition (transform.position);

		caterHead.Setup (this);
		caterTail.Setup (this);
	}

	KeyCode GetSuicideButton ()
	{
		#if UNITY_STANDALONE_OSX
		if (caterHead.playerNumber < 2)
			return KeyCode.Joystick1Button19;
		else
			return KeyCode.Joystick2Button19;
		#else
		if (caterHead.playerNumber < 2)
			return KeyCode.Joystick1Button3;
		else
			return KeyCode.Joystick1Button3;
		#endif
	}

	void Update ()
	{
		if (!isDying) {
			if (Input.GetKey (GetSuicideButton ())) {
				deathTime += Time.deltaTime;

				float power = (deathTime / deathTimeMax) * 2f;
				caterHead.rigidbody.AddForce (new Vector2 (Random.Range (-1f, 1f), Random.Range (-1f, 1f)) * power, ForceMode2D.Impulse);
				caterTail.rigidbody.AddForce (new Vector2 (Random.Range (-1f, 1f), Random.Range (-1f, 1f)) * power, ForceMode2D.Impulse);
			} else if (deathTime > 0f) {
				deathTime = 0f;
			}

			if (deathTime >= deathTimeMax) {
				Respawn ();
				deathTime = 0;
			}
		}
	}

	public void Respawn ()
	{
		if (!isDying)
			StartCoroutine (DoRespawn ());
	}

	IEnumerator DoRespawn ()
	{
		isDying = true;

		// find all spriterenderers and rbs
		SpriteRenderer[] allRenderers = gameObject.GetComponentsInChildren<SpriteRenderer> (true);
		Rigidbody2D[] rbs = gameObject.GetComponentsInChildren<Rigidbody2D> (true);

		List<Transform> pieces = new List<Transform> ();

		// get heads
		pieces.Add (caterHead.transform);
		pieces.Add (caterTail.transform);

		// get body segments
		SegmentBehavior[] segs = gameObject.GetComponentsInChildren<SegmentBehavior> (true);

		foreach (SegmentBehavior seg in segs)
			pieces.Add (seg.transform);

		// lock everything down
		foreach (Rigidbody2D rb in rbs) {
			rb.isKinematic = true;
		}

		// play yay
		SoundManager.instance.PlayYay ();

		GoTweenConfig config = new GoTweenConfig ();
		config.shake (Vector2.one * 0.2f);

		int totalPieces = pieces.Count;

		while (pieces.Count > 0) {
			float pieceDeathTime = 0.2f;
			Transform piece = pieces.PopRandom ();

			Go.to (piece, pieceDeathTime, config);

			yield return new WaitForSeconds (pieceDeathTime / 2f);

			for (int i = 0; i < allRenderers.Length; ++i) {
				if (allRenderers [i].transform.parent == piece || allRenderers [i].transform.parent.parent == piece) {
					allRenderers [i].enabled = false;
				}
			}

			smokePuff.transform.position = piece.position;
			smokePuff.Emit (25);

			// play "poof!"
			SoundManager.instance.PlayPop (totalPieces - pieces.Count);

		}

		yield return new WaitForSeconds (1f);

		// respawn, move element back
		transform.position = lastSpawnPoint;

		foreach (Transform t in originalPositions.Keys) {
			t.localPosition = originalPositions [t];
		}

		// show all sprites
		foreach (SpriteRenderer sr in allRenderers)
			sr.enabled = true;

		// release control to the player.
		foreach (Rigidbody2D rb in rbs) {
			if (!rb.transform.name.Contains ("Anchor"))
				rb.isKinematic = false;
		}

		// play "yay!"
		this.confettiPuff.Emit (30);
		this.confettiPuff.Play ();
		SoundManager.instance.PlayPartyBlower ();

		isDying = false;
		yield break;
	}

	public void SaveLastPosition (Vector3 point)
	{
		lastSpawnPoint = point;
	}
}
