﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class SoundManager : Singleton<SoundManager>
{
	public AudioClip gameEnd;
	public AudioClip theme;
	public AudioClip menu;
	public AudioClip falling1;
	public AudioClip falling2;

	public List<AudioClip> pops;
	public AudioClip yay, yay2;

	public AudioClip partyBlower;
	public AudioClip applause1, applause2;

	public AudioClip grunt;


	protected List<AudioSource> sources;
	protected AudioListener listener;

	void Awake ()
	{
		sources = new List<AudioSource> ();

		for (int i = 0; i < 4; ++i) {
			AudioSource s = gameObject.AddComponent<AudioSource> ();
			sources.Add (s);
		}

		listener = gameObject.AddComponent<AudioListener> ();

		falling1 = ResourceTools.Instantiate<AudioClip> ("Audio/falling1");
		falling2 = ResourceTools.Instantiate<AudioClip> ("Audio/falling2");
		theme = ResourceTools.Instantiate<AudioClip> ("Audio/theme_music");
		menu = ResourceTools.Instantiate<AudioClip> ("Audio/menu");
		gameEnd = ResourceTools.Instantiate<AudioClip> ("Audio/game_end");

		pops = new List<AudioClip> ();

		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop1"));
		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop2"));
		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop3"));
		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop4"));
		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop5"));
		pops.Add (ResourceTools.Instantiate<AudioClip> ("Effects/pop6"));

		yay = ResourceTools.Instantiate<AudioClip> ("Effects/yay");
		yay2 = ResourceTools.Instantiate<AudioClip> ("Effects/yay2");
		partyBlower = ResourceTools.Instantiate<AudioClip> ("Effects/party_blower");

		applause1 = ResourceTools.Instantiate<AudioClip> ("Effects/applause1");
		applause2 = ResourceTools.Instantiate<AudioClip> ("Effects/applause2");

		grunt = ResourceTools.Instantiate<AudioClip> ("Effects/grunt");

		base.Awake ();
	}

	public void PlayMenuTheme ()
	{
		AudioSource source = GetSource ();
		source.clip = menu;
		source.loop = true;
		source.volume = 0.15f;

		source.Play ();
	}

	public void PlayGameTheme ()
	{
		AudioSource source = GetSource ();
		source.clip = theme;
		source.loop = true;
		source.volume = 0.1f;

		source.Play ();
	}

	public void PlayFalling ()
	{
		AudioSource source = GetSource ();
		source.clip = Random.value < 0.5f ? falling1 : falling2;
		source.loop = false;

		source.Play ();
	}

	public void PlayPop (int i)
	{
		AudioSource source = GetSource ();
		source.clip = pops [i % pops.Count];
		source.loop = false;
		source.volume = 0.2f;

		source.Play ();
	}

	public void PlayYay ()
	{
		AudioSource source = GetSource ();
		source.clip = Random.value < 0.5f ? yay : yay2;
		source.loop = false;
		source.volume = 0.1f;

		source.Play ();
	}

	public void PlayPartyBlower ()
	{
		AudioSource source = GetSource ();
		source.clip = partyBlower;
		source.loop = false;
		source.volume = 0.15f;

		source.Play ();
	}

	public void PlayApplause ()
	{
		AudioSource source = GetSource ();
		source.clip = Random.value < 0.5f ? applause1 : applause2;
		source.loop = false;
		source.volume = 0.15f;

		source.Play ();
	}

	public void PlayEnding ()
	{
		AudioSource source = GetSource ();
		source.clip = gameEnd;
		source.loop = false;

		source.Play ();
	}

	public void PlayGrunt ()
	{
		AudioSource source = GetSource ();
		source.clip = grunt;
		source.loop = false;
		source.pitch = Random.Range (0.6f, 1.6f);
		source.volume = 0.1f;

		source.Play ();
	}

	public void StopAll ()
	{
		for (int i = 0; i < sources.Count; ++i) {
			sources [i].Stop ();
		}
	}

	private AudioSource GetSource ()
	{
		AudioSource result = null;

		for (int i = 0; i < sources.Count; ++i) {
			if (sources [i].isPlaying) {
				continue;
			} else {
				result = sources [i];
				break;
			}
		}

		if (result == null) {
			result = gameObject.AddComponent<AudioSource> ();
		}

		result.pitch = 1f;

		return result;
	}
}
