﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class UIManager : MonoBehaviour
{


	public Text LevelNumber;
	public GameObject PausePanel;
	public bool GamePaused;

	public Color SelectedColor;
	public Color UnSelectedColor;

	public bool ResumeSelected;
	public bool QuitSelected;

	public GameObject ResumeButton;
	public GameObject QuitButton;


	public bool ShiftedSelection;

	private string rightStick;
	private string leftStick;
	private string rightTrigger;
	private string leftTrigger;
	private KeyCode StartButton;
	private KeyCode AButton;

	// Use this for initialization
	void Start ()
	{
		//LevelNumber.text = SceneManager.GetActiveScene ().name;
		PausePanel.SetActive (false);
		GamePaused = false;
		ResumeSelected = true;
		QuitSelected = false;
		ShiftedSelection = false;
		this.leftStick = "LeftX";
		#if UNITY_STANDALONE_OSX
		this.rightStick = "RightX";
		this.rightTrigger = "RightTrigger";
		this.leftTrigger = "LeftTrigger";
		this.StartButton = KeyCode.Joystick1Button9;
		this.AButton = KeyCode.Joystick1Button16;

		#else
		this.rightStick = "RightXPC";
		this.rightTrigger = "RightTriggerPC";
		this.leftTrigger = "LeftTriggerPC";
		this.StartButton = KeyCode.Joystick1Button7;
		this.AButton = KeyCode.Joystick1Button0;

		#endif

	}
	
	// Update is called once per frame
	void Update ()
	{
		//Check below line if version is running on windows or mac later, cause input 
		if (Input.GetKeyUp ("p") || Input.GetKeyUp (this.StartButton)) { 
			if (!GamePaused) {
				LoadPausePanel ();
				GamePaused = true;
				ResumeSelected = true;
				QuitSelected = false;
				return;
			}
			if (GamePaused) {
				Unpause ();
				GamePaused = false;
				return;
			}
		}			

		

		if (GamePaused && ShiftedSelection == false) {
			if (Input.GetAxis (this.leftStick) == -1 || Input.GetAxis (this.rightStick) == -1 || Input.GetKeyUp (KeyCode.LeftArrow)) {
				if (ResumeSelected) // if resume is selected do nothing
					return;
				if (!ResumeSelected) {
					ResumeSelected = true;
					QuitSelected = false;
					ShiftedSelection = true;
				}
			}
			if (Input.GetAxis (this.leftStick) == 1 || Input.GetAxis (this.rightStick) == 1 || Input.GetKeyUp (KeyCode.RightArrow)) {
				if (!ResumeSelected) // if resume is not selected, do nothing
					return;
				if (ResumeSelected) {
					ResumeSelected = false;
					QuitSelected = true;
					ShiftedSelection = true;
				}
			}
		}
			
		if (Input.GetKeyUp (KeyCode.Space) || Input.GetKeyUp (this.AButton)) { //  and ||  input for xbox controlller here selection here
			ConfirmSelection ();
			return;
		}

		//code to check set shifted selected back to false if set at 0
		if (Input.GetAxis (this.rightStick) == 0 && Input.GetAxis (this.leftStick) == 0) {
			ShiftedSelection = false;
		}

		CheckColors ();
	}


	public void CheckColors ()
	{
		if (ResumeSelected) {
			ResumeButton.GetComponent<Image> ().color = SelectedColor;
			QuitButton.GetComponent<Image> ().color = UnSelectedColor;
			return;
		}
		if (QuitSelected) {
			ResumeButton.GetComponent<Image> ().color = UnSelectedColor;
			QuitButton.GetComponent<Image> ().color = SelectedColor;
			return;
		}

	}



	public void ConfirmSelection ()
	{
		if (ResumeSelected)
			Unpause ();
		if (QuitSelected)
			QuitToMain ();
	}

	public void LoadPausePanel ()
	{
		PausePanel.SetActive (true);
		Time.timeScale = 0;
	}

	

	public void Unpause ()
	{
		PausePanel.SetActive (false);
		Time.timeScale = 1;
		GamePaused = false;
	}

	public void QuitToMain ()
	{
		Time.timeScale = 1;
		SceneManager.LoadScene ("Start");

	}

}
