﻿using UnityEngine;
using System.Collections;
using UnityEngine.SceneManagement;

public class WinScreen : MonoBehaviour
{
	public GameObject cookieGet;
	public GameObject starburstGroup;
	public GameObject player;

	public SpriteRenderer head;
	public SpriteRenderer face;

	private Sprite faceOn;
	private Sprite faceOff;

	public static WinScreen instance;

	public bool isPlaying;

	void Start ()
	{
		instance = this;
		starburstGroup.SetActive (false);
		player.SetActive (false);
		cookieGet.SetActive (false);

		isPlaying = false;
	}

	public void PlayerWon (BodyGrabBehavior player)
	{
		if (isPlaying)
			return;

		isPlaying = true;

		head.sprite = player.mainSprite.sprite;
		face.sprite = player.overSlotOff;

		faceOff = player.overSlotOff;
		faceOn = player.overSlotOn;

		SoundManager.instance.StopAll ();
		SoundManager.instance.PlayApplause ();
		SoundManager.instance.PlayEnding ();
		StartCoroutine (FaceBlink ());
		StartCoroutine (MainAnimation ());
	}

	private IEnumerator FaceBlink ()
	{
		while (true) {
			
			face.sprite = faceOn;

			yield return new WaitForSeconds (Random.Range (0.4f, 0.8f));

			face.sprite = faceOff;

			yield return new WaitForSeconds (Random.Range (2f, 4f));
		}
	}

	private IEnumerator MainAnimation ()
	{
		GoTweenConfig config = new GoTweenConfig ();
		config.floatProp ("orthographicSize", 1.85f);
		config.setEaseType (GoEaseType.BackIn);

		Go.to (gameObject.transform.parent.GetComponent<Camera> (), 0.75f, config);

		yield return new WaitForSeconds (0.5f);

		cookieGet.SetActive (true);

		Vector3 cookieStart = cookieGet.transform.localPosition + (Vector3.up * 3f);
		config.clearProperties ();
		config.localPosition (cookieStart);
		config.setEaseType (GoEaseType.BackOut);

		Go.from (cookieGet.transform, 0.8f, config);

		// bring in face
		player.SetActive (true);

		config.clearProperties ();
		config.scale (Vector3.zero);
		config.setEaseType (GoEaseType.BackOut);

		Go.from (player.transform, 1.25f, config);

		// bring in starburst
		starburstGroup.SetActive (true);

		Transform[] stars = starburstGroup.GetComponentsInChildren<Transform> ();

		for (int i = 0; i < stars.Length; ++i) {
			
			if (stars [i] == starburstGroup.transform) {
				continue;
			}
			
			config.clearProperties ();
			config.localRotation (Quaternion.AngleAxis (180f * Mathf.Sign (Random.Range (-1f, 1f)), Vector3.forward));
			config.setEaseType (GoEaseType.SineInOut);
			config.loopType = GoLoopType.PingPong;
			config.setIterations (-1);

			Go.to (stars [i], Random.Range (2f, 5f), config);

			SpriteRenderer starRenderer = stars [i].GetComponent<SpriteRenderer> ();

			config.clearProperties ();
			config.colorProp ("color", new Color (1f, 1f, 1f, 0f));
			config.setEaseType (GoEaseType.QuartIn);
			config.setIterations (1);
			Go.from (starRenderer, 1f, config);
		}

		yield return new WaitForSeconds (8f);
		SceneManager.LoadScene ("Start");

	}
}
